/**
 *  Java GUI Tutorial 
 *  ListBoxExample.java
 *
 *  @autor Gabor Nemeth, HUNGARY 2007
 *    
 *  Licence: free for non-commercial use
 *
 *  This is a sample program without guarantee and liability.
 *  
 *
 **/


import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;


public class ListBoxExample extends JFrame implements ActionListener, ItemListener {
  
  private JPanel mainPanel;
  private JLabel label;
  private List list1, list2;
  private JButton addButton;
  private JButton removeButton;
  private JPanel buttonPanel;
  
  public ListBoxExample() {
    super( "ListBoxExample" );
    setSize( 400, 150 );
    mainPanel = new JPanel();
    mainPanel.setLayout( new BorderLayout() );
    buttonPanel = new JPanel();
    buttonPanel.setLayout( new GridLayout( 2, 1 ) );
    addButton = new JButton( "Add >>" );
    removeButton = new JButton( "<< Remove" );
    label = new JLabel( "The selected item: " );
    list1 = new List( 5, true );  // 5 items are visible and 
                                  // multiple selection is enabled
    list2 = new List( 5, false ); 
    list1.add( "Egg" );
    list1.add( "Bread" );
    list1.add( "Cheese" );
    list1.add( "Wine" );
    list1.add( "Coke" );
    list1.add( "Toast" );
    list1.add( "Pepper" );
    list1.add( "Tomato" );
    list1.add( "Potato" );
    list1.add( "Mustard" );
    
    // now list2 is empty
    
    list1.addItemListener( this );
    list2.addItemListener( this );
    
    addButton.addActionListener( this );
    removeButton.addActionListener( this );
    
    // setting the layout
    this.getContentPane().add( mainPanel );
    mainPanel.add( list1, BorderLayout.WEST );
    mainPanel.add( list2, BorderLayout.EAST );
    mainPanel.add( buttonPanel, BorderLayout.CENTER );
    mainPanel.add( label, BorderLayout.SOUTH );
    buttonPanel.add( addButton );
    buttonPanel.add( removeButton );
    
    addButton.setEnabled( false );
    removeButton.setEnabled( false );
    
    
  }
  
  // list event handling
  public void itemStateChanged( ItemEvent e ) {
    if ( e.getSource().equals( list1 ) ) {
      
      // deselect all items in list2
      for ( int i = 0; i < list2.getItemCount(); i++ ) {
          list2.deselect( i ); 
      }
      
      String[] selectedItems = list1.getSelectedItems();
      if ( selectedItems.length > 1 ) {
        label.setText( "Would you add these items to the list?" );
      } else if ( selectedItems.length == 1 ) {
        label.setText( "Would you add this item to the list?" );
      }
      if ( selectedItems.length != 0 ) {
        this.addButton.setEnabled( true );
      } else {
        this.addButton.setEnabled( false );
      }
      this.removeButton.setEnabled( false );
    }
    
    if ( e.getSource().equals( list2 ) ) {
      
      // deselect all items in list1
      for ( int i = 0; i < list1.getItemCount(); i++ ) {
          list1.deselect( i ); 
      }
      
      String selectedItem = list2.getSelectedItem();
      if ( selectedItem != null ) {
        label.setText( "Would you remove this item from the list?" );
      }
      if ( selectedItem != null ) {
        this.removeButton.setEnabled( true );
      } else {
        this.removeButton.setEnabled( false );
      }
      this.addButton.setEnabled( false );
      
    }
  }
  
  // button event handling
  public void actionPerformed( ActionEvent e ) {
    
    if ( e.getSource().equals( addButton ) ) {
      String[] selectedItems = list1.getSelectedItems();
      for ( int i = selectedItems.length - 1; i >= 0; i-- ) {
        list1.remove( selectedItems[i] );
        list2.add( selectedItems[i] );
      }
      addButton.setEnabled( false );
    }
    if ( e.getSource().equals( removeButton ) ) {
      String selectedItem = list2.getSelectedItem(); //only one can be selected
      
      list2.remove( selectedItem );
      list1.add( selectedItem );
      
      removeButton.setEnabled( false );
    }
  }
  
  public static void main( String[] args ) {
    ListBoxExample frame = new ListBoxExample();
    frame.setVisible( true );
    
    // this is an implementation of window listener
    // the program will be stopped if you close the main frame
    WindowListener listener = new WindowAdapter() {
      public void windowClosing(WindowEvent we) {
        System.exit(0);
      }
    };
    frame.addWindowListener(listener);
  }
}